# Security Policy

## Reporting a Vulnerability

We take the security of Kanoniv seriously. If you believe you have found a security vulnerability in the specification or any of the open-source tools, please report it to us by emailing security@kanoniv.com.

Please do **not** open a public GitHub issue for security vulnerabilities.

### What to include in your report

* A description of the vulnerability.
* Steps to reproduce the issue.
* Any potential impact you've identified.

### Our Commitment

* We will acknowledge receipt of your report within 48 hours.
* We will send you updates on our progress as we investigate and address the issue.
* We will credit you for your discovery in our security advisories (if you wish).
